@@ -4,11 +4,8 @@ from cgdb.exceptions.EntityNotFound import EntityNotFoundException
 
 
 class ManagerMix:
-    def __init__(self, client, url_stack=None):
-        if url_stack is None:
-            url_stack = []
+    def __init__(self, client):
         self._client = client
-        self._url_stack = url_stack
 
     def get(self, url=""):
         raw_content = self._client._session.get(url)
